=========
Amplitude
=========

Amplitude commands are used to create arbitrary time or frequency variations of load, displacement, and some interaction attributes throughout a step using step time or throughout an analysis using total time.

Create amplitudes
-----------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Amplitude.AmplitudeModel.AmplitudeModel
    :noindex:

    .. autoclasstoc::


In Odb
~~~~~~

.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
